summaryrefslogtreecommitdiffstats
path: root/kdecore/kiconloader.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /kdecore/kiconloader.h
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdecore/kiconloader.h')
-rw-r--r--kdecore/kiconloader.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kdecore/kiconloader.h b/kdecore/kiconloader.h
index b9d6c7714..f8ac3fbc7 100644
--- a/kdecore/kiconloader.h
+++ b/kdecore/kiconloader.h
@@ -106,7 +106,7 @@ public:
void addAppDir(const TQString& appname);
/**
* Loads an icon. It will try very hard to tqfind an icon which is
* suitable. If no exact match is found, a close match is searched.
* If neither an exact nor a close match is found, a null pixmap or
* the "unknown" pixmap is returned, depending on the value of the
@@ -372,10 +372,10 @@ public:
/**
* @internal
* tries to tqfind an icon with the name. It tries some extension and
* match strategies
*/
- KIcon tqfindMatchingIcon(const TQString& name, int size) const;
+ KIcon findMatchingIcon(const TQString& name, int size) const;
/**
* @internal
@@ -424,7 +424,7 @@ public:
* Same as removeIconExtension except it prints a debug message
* if an extension is removed to help catch programming errors.
*
- * @see tqfindMatchingIcon()
+ * @see findMatchingIcon()
* @see iconPath()
*
* TODO: KDE 4 make static
@@ -106,7 +106,7 @@ public:
void addAppDir(const TQString& appname);
/**
- * Loads an icon. It will try very hard to tqfind an icon which is
+ * Loads an icon. It will try very hard to find an icon which is
* suitable. If no exact match is found, a close match is searched.
* If neither an exact nor a close match is found, a null pixmap or
@@ -372,10 +372,10 @@ public:
/**
* @internal
- * tries to tqfind an icon with the name. It tries some extension and
+ * tries to find an icon with the name. It tries some extension and
* match strategies
*/